@@ -696,7 +696,7 @@ class DensityFlow(nn.Module):
         """
         Return the mean part of metacell codebook
         """
-        cb = self._get_metacell_coordinates()
+        cb = self._get_codebook()
         cb = tensor_to_numpy(cb)
         return cb
 
@@ -842,10 +842,10 @@ class DensityFlow(nn.Module):
         
         return counts, zs
     
-    def _cell_response(self, zs_basal, perturb_idx, perturb):
+    def _cell_response(self, zs, perturb_idx, perturb):
         #zns,_ = self.encoder_zn(xs)    
         #zns,_ = self._get_basal_embedding(xs)   
-        zns = zs_basal
+        zns = zs
         if perturb.ndim==2:
             ms = self.cell_factor_effect[perturb_idx]([zns, perturb])
         else:
@@ -854,7 +854,7 @@ class DensityFlow(nn.Module):
         return ms 
 
     def get_cell_response(self, 
-                             zs_basal, 
+                             zs, 
                              perturb_idx,
                              perturb_us,
                              batch_size: int = 1024):
@@ -863,9 +863,9 @@ class DensityFlow(nn.Module):
 
         """
         #xs = self.preprocess(xs)
-        zs_basal = convert_to_tensor(zs_basal, device=self.get_device())
+        zs = convert_to_tensor(zs, device=self.get_device())
         ps = convert_to_tensor(perturb_us, device=self.get_device())
-        dataset = CustomDataset2(zs_basal,ps)
+        dataset = CustomDataset2(zs,ps)
         dataloader = DataLoader(dataset, batch_size=batch_size, shuffle=False)
 
         Z = []
@@ -878,12 +878,6 @@ class DensityFlow(nn.Module):
         Z = np.concatenate(Z)
         return Z
     
-    def get_metacell_response(self, factor_idx, perturb):
-        zs = self._get_codebook()
-        ps = convert_to_tensor(perturb, device=self.get_device())         
-        ms = self.cell_factor_effect[factor_idx]([zs,ps])
-        return tensor_to_numpy(ms)
-    
     def _get_expression_response(self, delta_zs):
         return self.decoder_concentrate(delta_zs)
     
